<?php 
class WCEV_Country
{
	public function __construct()
	{
		add_action('wp_ajax_wcev_load_state_by_country_id', array(&$this, 'ajax_load_state_by_country_id'));
		add_action('wp_ajax_nopriv_wcev_load_state_by_country_id', array(&$this, 'ajax_load_state_by_country_id'));
	}
	function ajax_load_state_by_country_id()
	{
		$country_id = isset($_POST['country_id']) ? $_POST['country_id'] : "";
		if($country_id != "")
			$this->render_state_select_html_by_country($country_id);
		wp_die();
	}
	function render_state_select_html_by_country($country_id, $default_val = null, $use_wide_row = false)
	{
		$countries_obj   = new WC_Countries();
		$states = $countries_obj->get_states( $country_id ); //paramenter -> GB, IT ... is the "value" selected in the $countries select box
		$label_data =  $countries_obj->get_country_locale();
		
		$custom_attributes = array();
		
		if ( is_array( $states ) && empty( $states ) ) //Like Germany, it doesn't have a states/provinces
		{
			woocommerce_form_field('billing_state', array(
							'type'       => 'hidden',
							'class'      => $use_wide_row ? array( 'form-row-wide' ) : array( 'form-row-last' ),
							'label'      => $label_data[$country_id]['state']['label'],
							'label_class' => array( 'wcev_form_label' ),
							//'placeholder'    => __('Select a state','wp-user-extra-fields'),
							'value'    => $states
							));
		}
		elseif(is_array($states)) //Ex.: Italy
		{
			$reordered_states = array();
			$reordered_states[""] = __('Select one','wp-user-extra-fields');
			foreach($states as $state_code => $state_name)
				$reordered_states[$state_code] = $state_name;
			
			$required = isset($label_data[$country_id]['state']['required']) ? $label_data[$country_id]['state']['required'] : false;
			$custom_attributes['required'] = $required; 
			woocommerce_form_field('billing_state', array(
							'type'       => 'select',
							'required'          => $required,
							'class'      => $use_wide_row ? array( 'form-row-wide', 'select2-container' ) : array( 'form-row-last', 'select2-container' ),
							'label'      => $label_data[$country_id]['state']['label'],//__('State / Province','wp-user-extra-fields'),
							'label_class' => array( 'wcev_form_label' ),
							'input_class' => array('select2-choice', 'wpuef_state_selector', "wpuef_element"),
							//'placeholder'    => __('Select a state','wp-user-extra-fields'),
							'custom_attributes' =>  $custom_attributes,
							'options'    => $reordered_states,
							'default' => isset($default_val) ? $default_val : ""
							)
			);
		}
		else //$states is false. Ex.: UK
		{
			$required = isset($label_data[$country_id]['state']['required']) ? $label_data[$country_id]['state']['required'] : false;
			$custom_attributes['required'] = $required; 
			woocommerce_form_field('billing_state', array(
						'type'       => 'text',
						'class'      => $use_wide_row ? array( 'form-row-wide' ) : array( 'form-row-last' ),
						'required'          => $required,
						'input_class' => array('wcmca_input_field'),
						'label'      => $label_data[$country_id]['state']['label'],//__('State / Province','wp-user-extra-fields'),
						'label_class' => array( 'wcev_form_label' ),
						//'placeholder'    => __('State / Country','wp-user-extra-fields'),
						'custom_attributes' =>  $custom_attributes,
						'default' => isset($default_val) ? $default_val : ""
						)
						);
		}
	}
	function isEU($countrycode)
	{
		global $wcev_vat_field_model;
		$countries = WC()->countries;
		
		$eu_countrycodes =  version_compare( wcev_get_woo_version_number(), '4', '<' ) ? $countries->get_european_union_countries( 'eu_vat' ) : $countries->get_vat_countries();
		//missing: CH, NO (Norway), RS (Serbia)
		/* array(
			'AT', 'BE', 'BG', 'CY', 'CZ', 'DE', 'DK', 'EE', 'EL', 'GR',
					'ES', 'FI', 'FR', 'GB', 'HR', 'HU', 'IE', 'IT', 'LT', 'LU', 'LV',
					'MT', 'NL', 'PL', 'PT', 'RO', 'SE', 'SI', 'SK'  
		); */
		
		if( !empty($country_to_exclude = $wcev_vat_field_model->get_all_options('disabled_eu_countries')))
			if(($key = array_search($country_to_exclude, $eu_countrycodes)) !== false) 
				unset($eu_countrycodes[$key]);	
				
		return(in_array($countrycode, $eu_countrycodes));
    }
	public function get_allowed_countries_list_for_register_page()
	{
		global $wcev_vat_field_model;
		$countries = WC()->countries;
		$shipping_countries = $countries->get_shipping_countries();
		$eu_countries = version_compare( wcev_get_woo_version_number(), '4', '<' ) ? $countries->get_european_union_countries( 'eu_vat' ) : $countries->get_vat_countries();
		$all_countries = $countries->get_countries();
		
		//wcev_var_dump($all_countries);
		if(empty($shipping_countries))
			return array();
		
		if( !empty($country_to_exclude = $wcev_vat_field_model->get_all_options('disabled_eu_countries')))
			if(($key = array_search($country_to_exclude, $eu_countries)) !== false) 
				unset($eu_countries[$key]);	
			
		if( !empty($country_to_exclude = $shipping_countries))
			if(($key = array_search($country_to_exclude, $eu_countries)) !== false) 
				unset($eu_countries[$key]);	
			
		$final_result = array();
		foreach($eu_countries as $eu_country_code)
			$final_result[$eu_country_code] = $all_countries[$eu_country_code];
			
		return $final_result;
	}
	function get_eu_vat_country_codes()
	{
		$countries = WC()->countries;
		return version_compare( wcev_get_woo_version_number(), '4', '<' ) ? $countries->get_european_union_countries( 'eu_vat' ) : $countries->get_vat_countries();
	}
}
?>