<?php 
class WCEV_Customer
{
	//var $is_vat_exempt = false;
	
	public function __construct()
	{
		add_action('wp_ajax_wcev_load_vat_data', array(&$this, 'ajax_get_user_vat'));
		add_action('init', array(&$this, 'disable_if_necessary_exemption'));
		add_filter( 'woocommerce_ajax_get_customer_details', array(&$this, 'add_vat_data_to_user_details_ajax_request'), 10, 3 );		
	}
	static function is_vat_exempt($user = null)
	{
		$user = !isset($user) && WC()->customer != null ? WC()->customer : null;
		if(!isset($user))
			return false;
		
		if(version_compare( WC_VERSION, '2.7', '<' ))
			return $user->is_vat_exempt( );
		
		return $user->get_is_vat_exempt( );
	}
	function disable_if_necessary_exemption()
	{
		if(WC()->customer == null)
			return; 
		
		global $wcev_vat_field_model;
		$options = $wcev_vat_field_model->get_all_options();
		//wcev_var_dump(WCEV_Customer::is_vat_exempt(WC()->customer));
		//wcev_var_dump($options['tax_removal']);
		if($options['disable_eu_vat_field'] || !$options['tax_removal'])
			WC()->customer->set_is_vat_exempt(false);
	}
	public function set_vat_exemption($is_exempt, $user_id = null)
	{
		if(WC()->customer == null)
			return; 
		
		//$this->is_vat_exempt = $is_exempt;
		if( isset( $user_id))
		{
			$wc_customer = new WC_Customer($user_id);
			if(isset($wc_customer) && $wc_customer != false)
			{
				$wc_customer->set_is_vat_exempt($is_exempt, $user_id);
				$wc_customer->save();
			}
		}	
		else
			WC()->customer->set_is_vat_exempt($is_exempt);
	}
	public function is_elegible_for_vat_exemption($billing_country = null)
	{
		global $wcev_vat_field_model;
		$options = $wcev_vat_field_model->get_all_options();
		$base_location = wc_get_base_location();
		if($billing_country == null && get_current_user_id() > 0 )
		{
			$wc_user = new WC_Customer(get_current_user_id());
			$billing_country = $wc_user->get_billing_country();
		}
		
		/* if(!isset($billing_country))
			return false; */
		
		if($options['tax_removal'] &&  ($options['tax_removal_for_local_based_users'] || $base_location['country'] != $billing_country /* $params['billing_country'] */))
			return true;
		
		return false;
	}
	public function is_admin_or_shop_manager()
	{
		if(!is_user_logged_in())
			return false;
		
		
		$user =  wp_get_current_user();
		if($user && (in_array('administrator', $user->roles) || in_array('shop_manager', $user->roles)))
						return true;
					
		return false;
	}
	public function ajax_get_user_vat()
	{
		$user_id = isset($_POST['user_id']) ? $_POST['user_id'] : 0;
		$return_value = array('vat_number'=>'', 'request_invoice'=>'no');
		if($user_id > 0)
		{
			$return_value['vat_number'] = $this->get_vat_number($user_id);
			$return_value['request_invoice'] = $this->was_invoice_requested($user_id);
		}
		echo json_encode($return_value);
		wp_die();
	}
	public function get_customer_meta($user_id, $key)
	{
		if(!isset($user_id) || !isset($key))
			return false;
		
		return get_user_meta($user_id, $key, true);
	}
	public function set_customer_meta($user_id, $key, $value)
	{
		if(!isset($user_id) || !isset($key))
			return false;
		
		return update_user_meta($user_id, $key, $value, true);
	}
	public function add_vat_data_to_user_details_ajax_request($data, $customer, $user_id)
	{
		$data['billing']['eu_vat'] = $this->get_vat_number($user_id);
		$data['billing']['request_eu_vat'] = $this->was_invoice_requested($user_id);
		
		return $data;
	}
	//getters
	public function get_vat_number($user_id = null)
	{
		$user_id = !isset($user_id) ? get_current_user_id() : $user_id;
		if($user_id == 0)
			return "";
		
		$vat_number = $this->get_customer_meta($user_id, 'billing_eu_vat');
		return isset($vat_number) ? $vat_number : "";
	}
	public function get_sdi_pec($user_id = null)
	{
		$user_id = !isset($user_id) ? get_current_user_id() : $user_id;
		if($user_id == 0)
			return "";
		
		$result = $this->get_customer_meta($user_id, 'billing_it_sid_pec');
		return isset($result) ? $result : "";
	}
	public function get_codice_fiscale($user_id = null)
	{
		$user_id = !isset($user_id) ? get_current_user_id() : $user_id;
		if($user_id == 0)
			return "";
		
		$result = $this->get_customer_meta($user_id, 'billing_it_codice_fiscale');
		return isset($result) ? $result : "";
	}
	public function get_es_nif_nie($user_id = null)
	{
		$user_id = !isset($user_id) ? get_current_user_id() : $user_id;
		if($user_id == 0)
			return "";
		
		$result = $this->get_customer_meta($user_id, 'billing_es_nif_nie');
		return isset($result) ? $result : "";
	}
	public function was_invoice_requested($user_id)
	{
		return $this->get_customer_meta($user_id, 'billing_request_eu_vat');
	}
	public function is_vat_number_already_associated_to_a_customer($vat, $user_id = null)
	{
		if(!isset($vat) || $vat == "")
			return false;
		
		$user_id = !isset($user_id) ? get_current_user_id() : $user_id;
		
		global $wpdb;
		$query = "SELECT user_id 
				  FROM {$wpdb->usermeta} 
				  WHERE meta_key = 'billing_eu_vat'
				  AND meta_value = '{$vat}'";
				  
		$results = $wpdb->get_results($query);
		
		if(!empty($results))
		{
			foreach($results as $result)
				if($result->user_id == $user_id)
					return false;
		}
		else 
			return false;
		
		
		return true;
		
	}
	//setters
	public function set_billing_country($user_id, $value)
	{
		return $this->set_customer_meta($user_id, 'billing_country',$value);
	}
	public function set_billing_company($user_id, $value)
	{
		return $this->set_customer_meta($user_id, 'billing_company',$value);
	}
	public function set_vat_number($user_id, $value)
	{
		return $this->set_customer_meta($user_id, 'billing_eu_vat',$value);
	}
	public function set_codice_fiscale($user_id)
	{
		return $this->set_customer_meta($user_id, 'billing_it_codice_fiscale',$value);
	}
	public function set_sdi_pec($user_id)
	{
		return $this->set_customer_meta($user_id, 'billing_it_sid_pec',$value);
	}
	public function set_es_nif_nie($user_id)
	{
		return $this->set_customer_meta($user_id, 'billing_es_nif_nie',$value);
	}
	public function set_invoice_request($user_id)
	{
		return $this->set_customer_meta($user_id, 'billing_request_eu_vat',$value);
	}
	
}
?>