<?php
class WCEV_RegisterPage
{ 
	function __construct()
	{
		add_action('user_register', array( &$this,'save_user_data_after_registration'));
		//add_filter( 'registration_errors', array( &$this,'validate_user_data'), 10, 3 );
		add_filter( 'woocommerce_registration_errors', array( &$this,'validate_user_data'), 10, 3 );
		add_action('woocommerce_register_form',array( &$this, 'add_vat_fields_to_register_form')); //after form: woocommerce_register_form_start
	}
	
	function save_user_data_after_registration($user_id)
	{
		global $wcev_vat_field_model, $wcev_customer_model;
		//Wc_customer -> save billing data and WCEV_Customer save eu vat number
		$options =  $wcev_vat_field_model->get_all_options();
		$render_eu_vat_field = $options['register_page_only_business_can_register'];
		$render_billing_company_field = $options['register_page_show_billing_company_field'];
		$billing_company_field_is_required = $options['register_page_show_billing_company_field_is_mandatory'];
		
		if(!$render_eu_vat_field)
			return;
		
		$is_billing_eu_vat_ok = isset($_POST['billing_eu_vat']) && $_POST['billing_eu_vat'] != '';
		$is_billing_country_ok = isset($_POST['billing_country']) && $_POST['billing_eu_vat'] != '';
		$is_billing_company_ok = isset($_POST['billing_company']) && $_POST['billing_company'] != '';
		$is_billing_state_ok = isset($_POST['billing_state']) && $_POST['billing_state'] != '';
		
		if($is_billing_country_ok)
			$wcev_customer_model->set_billing_country($user_id, $_POST['billing_country']);
		
		if($is_billing_company_ok)
			$wcev_customer_model->set_billing_company($user_id, $_POST['billing_company']);
		
		if($is_billing_state_ok)
			$wcev_customer_model->set_customer_meta($user_id, 'billing_state', $_POST['billing_state']);
		
		if($is_billing_eu_vat_ok)
		{
			$wcev_customer_model->set_vat_number($user_id, $_POST['billing_eu_vat']);
		}
		if($is_billing_country_ok && $is_billing_eu_vat_ok)
		{
			if($wcev_customer_model->is_elegible_for_vat_exemption($_POST['billing_country']))
				$wcev_customer_model->set_vat_exemption(true, $user_id);
		}
		
		//Remove taxes if necessary
	}
	function validate_user_data($errors, $username, $email )
	{
		global $wcev_vat_field_model, $wcev_text_helper, $wcev_customer_model;
		$options =  $wcev_vat_field_model->get_all_options();
		$render_eu_vat_field = $options['register_page_only_business_can_register'];
		$render_billing_company_field = $options['register_page_show_billing_company_field'];
		$billing_company_field_is_required = $options['register_page_show_billing_company_field_is_mandatory'];
		$perform_uniqueness_check = $options['enable_uniqueness_check']; 
		$texts = $wcev_text_helper->get_texts();
		
		if ( $render_eu_vat_field ) 
		{
			$is_billing_eu_vat_ok = isset($_POST['billing_eu_vat']) && $_POST['billing_eu_vat'] != '';
			$is_billing_country_ok = isset($_POST['billing_country']) && $_POST['billing_eu_vat'] != '';
			
			if(!$is_billing_eu_vat_ok)
				$errors->add( 'wcev_eu_vat_invalid_field', __( 'Invalid EU Vat number cannot be empty.', 'woocommerce-eu-vat-field' ) );
			else 
				if($perform_uniqueness_check && $wcev_customer_model->is_vat_number_already_associated_to_a_customer($_POST['billing_eu_vat']))
				{
					$errors->add( 'wcev_eu_vat_invalid_field', $texts['unique_vat_number_check_fail_text']); 
				}
		
			if(!$is_billing_country_ok)
				$errors->add( 'wcev_billing_country_field', __( 'Billing country cannot be empty.', 'woocommerce-eu-vat-field' ) );
			
			//Validation 
			if($is_billing_eu_vat_ok && $is_billing_country_ok && !$wcev_vat_field_model->validate_vat($_POST['billing_country'], $_POST['billing_eu_vat']))
				$errors->add( 'wcev_eu_vat_invalid_field', $texts['error_text'] );
			
			//Todo: check on is unique vat?
			
			if($render_billing_company_field && $billing_company_field_is_required && (!isset($_POST['billing_company']) || $_POST['billing_company'] == ''))
				$errors->add( 'wcev_eu_vat_billing_company_field', __( 'Billing company name cannot be empty.', 'woocommerce-eu-vat-field' ) );
        }
		 
		return $errors;
	}
	function add_vat_fields_to_register_form()
	{
		global  $wcev_vat_field_model, $wcev_text_helper, $wcev_country_helper;
		
		$options =  $wcev_vat_field_model->get_all_options();
		$texts = $wcev_text_helper->get_texts();
		$render_eu_vat_field = $options['register_page_only_business_can_register'];
		$render_billing_company_field = $options['register_page_show_billing_company_field'];
		$billing_company_field_is_required = $options['register_page_show_billing_company_field_is_mandatory'];
		$show_state = $options['b2b_show_state_field'];
		$allowed_countries_list = $wcev_country_helper->get_allowed_countries_list_for_register_page();
		
		if(!$render_eu_vat_field)
			return;
		
		//In case of validation error, data form will be refilled with already existing info
		$already_posted_company = wcev_get_value_if_set($_POST, 'billing_company', "");
		$already_posted_country = wcev_get_value_if_set($_POST, 'billing_country', "");
		$already_posted_vat_number = wcev_get_value_if_set($_POST, 'billing_eu_vat', "");
		
		$location = WC_Geolocation::geolocate_ip();
		$country_name = isset($location) ? $location['country'] : "";
		
		wp_enqueue_style( 'wcev-select2', WCEV_PLUGIN_PATH.'/css/vendor/select2/select2.min.css' );
		wp_enqueue_style( 'wcev-register-page', WCEV_PLUGIN_PATH.'/css/frontend-register-page.css' );
		wp_enqueue_script( 'selectWoo' );
		wp_enqueue_script( 'wcev-field-register-page', WCEV_PLUGIN_PATH.'/js/frontend-register-page.js', array('jquery') );
		$js_vars = array(
						'ajax_url' => admin_url('admin-ajax.php'),
					);
		wp_localize_script( 'wcev-field-register-page', 'wcev', $js_vars );
		
		woocommerce_form_field('billing_country', array(
									'label'     => __( 'Billing country', 'woocommerce-eu-vat-field' ),
									'placeholder'   => __( 'Billing country', 'woocommerce-eu-vat-field' ),
									'required'  => true,
									'class'     => array('form-row-first'),
									'input_class' => array('wcev_country_selector'),
									'clear'     => true,
									'validate' => array('wcev-billing-country'),
									'type' => 'select',
									'options' => $allowed_countries_list,
									'default' => $already_posted_country != "" ? $already_posted_country : $country_name
									)
							  );
		
		if($show_state): ?>
		<div id="wcev_state_selector">
		</div>
		<img class="wcev_preloader_image" id="wcev_preloader_image" src="<?php echo WCEV_PLUGIN_PATH.'/img/loader.gif' ?>" ></img>
		<?php endif;	
		
		woocommerce_form_field('billing_eu_vat', array(
									'label'     => $texts['field_label'],
									'placeholder'   => $texts['field_place_holder'],
									'required'  => true,
									'class'     => $show_state ? array( 'form-row-wide' ) : array('form-row-last'),
									'clear'     => true,
									'validate' => array('wcev-eu-vat'),
									'default' => $already_posted_vat_number
									)
							  );
		
		if(!$render_billing_company_field)
			return;		
		woocommerce_form_field('billing_company', array(
									'label'     => __( 'Billing company', 'woocommerce-eu-vat-field' ),
									'placeholder'   => __( 'Billing company', 'woocommerce-eu-vat-field' ),
									'required'  => $billing_company_field_is_required,
									'class'     => array('form-row-wide'),
									'clear'     => true,
									'validate' => array('wcev-eu-vat'),
									'default' => $already_posted_company
									)
							  );
	}
}
?>